@@ -21,6 +21,7 @@ import logging
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
+from osc_lib.utils import columns as column_util
 
 from neutronclient._i18n import _
 from neutronclient.osc import utils as osc_utils
@@ -32,13 +33,13 @@ LOG = logging.getLogger(__name__)
 _formatters = {}
 
 _attr_map = (
-    ('id', 'ID', osc_utils.LIST_BOTH),
-    ('name', 'Name', osc_utils.LIST_BOTH),
-    ('firewall_rules', 'Firewall Rules', osc_utils.LIST_BOTH),
-    ('description', 'Description', osc_utils.LIST_LONG_ONLY),
-    ('audited', 'Audited', osc_utils.LIST_LONG_ONLY),
-    ('shared', 'Shared', osc_utils.LIST_LONG_ONLY),
-    ('tenant_id', 'Project', osc_utils.LIST_LONG_ONLY),
+    ('id', 'ID', column_util.LIST_BOTH),
+    ('name', 'Name', column_util.LIST_BOTH),
+    ('firewall_rules', 'Firewall Rules', column_util.LIST_BOTH),
+    ('description', 'Description', column_util.LIST_LONG_ONLY),
+    ('audited', 'Audited', column_util.LIST_LONG_ONLY),
+    ('shared', 'Shared', column_util.LIST_LONG_ONLY),
+    ('tenant_id', 'Project', column_util.LIST_LONG_ONLY),
 )
 
 
@@ -79,9 +80,9 @@ def _get_common_attrs(client_manager, parsed_args, is_create=True):
         attrs['name'] = str(parsed_args.name)
     if parsed_args.description:
         attrs['description'] = str(parsed_args.description)
-    if parsed_args.share or parsed_args.public:
+    if parsed_args.share:
         attrs['shared'] = True
-    if parsed_args.no_share or parsed_args.private:
+    if parsed_args.no_share:
         attrs['shared'] = False
     return attrs
 
@@ -106,19 +107,6 @@ def _get_common_parser(parser):
         help=_('Share the firewall policy to be used in all projects '
                '(by default, it is restricted to be used by the '
                'current project).'))
-    shared_group.add_argument(
-        '--public',
-        action='store_true',
-        help=_('Make the firewall policy public, which allows it to be '
-               'used in all projects (as opposed to the default, which '
-               'is to restrict its use to the current project.) This '
-               'option is deprecated and would be removed in R release.'))
-    shared_group.add_argument(
-        '--private',
-        action='store_true',
-        help=_(
-            'Restrict use of the firewall policy to the current project.'
-            'This option is deprecated and would be removed in R release.'))
     shared_group.add_argument(
         '--no-share',
         action='store_true',
@@ -155,7 +143,7 @@ class CreateFirewallPolicy(command.ShowOne):
         attrs = _get_common_attrs(self.app.client_manager, parsed_args)
         obj = client.create_fwaas_firewall_policy(
             {const.FWP: attrs})[const.FWP]
-        columns, display_columns = osc_utils.get_columns(obj, _attr_map)
+        columns, display_columns = column_util.get_columns(obj, _attr_map)
         data = utils.get_dict_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
@@ -297,7 +285,7 @@ class ListFirewallPolicy(command.Lister):
     def take_action(self, parsed_args):
         client = self.app.client_manager.neutronclient
         obj = client.list_fwaas_firewall_policies()[const.FWPS]
-        headers, columns = osc_utils.get_column_definitions(
+        headers, columns = column_util.get_column_definitions(
             _attr_map, long_listing=parsed_args.long)
         return (headers, (utils.get_dict_properties(
             s, columns, formatters=_formatters) for s in obj))
@@ -360,7 +348,7 @@ class ShowFirewallPolicy(command.ShowOne):
                                       parsed_args.firewall_policy,
                                       cmd_resource=const.CMD_FWP)['id']
         obj = client.show_fwaas_firewall_policy(fwp_id)[const.FWP]
-        columns, display_columns = osc_utils.get_columns(obj, _attr_map)
+        columns, display_columns = column_util.get_columns(obj, _attr_map)
         data = utils.get_dict_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
@@ -402,12 +390,6 @@ class UnsetFirewallPolicy(command.Command):
             action='store_true',
             help=_('Restrict use of the firewall policy to the '
                    'current project'))
-        parser.add_argument(
-            '--public',
-            action='store_true',
-            help=_('Restrict use of the firewall policy to the '
-                   'current project. This option is deprecated '
-                   'and would be removed in R release.'))
         return parser
 
     def _get_attrs(self, client_manager, parsed_args):
@@ -427,7 +409,7 @@ class UnsetFirewallPolicy(command.Command):
             attrs[const.FWRS] = []
         if parsed_args.audited:
             attrs['audited'] = False
-        if parsed_args.share or parsed_args.public:
+        if parsed_args.share:
             attrs['shared'] = False
         return attrs
 
