@@ -20,25 +20,25 @@ import operator
 import mock
 from osc_lib import exceptions
 from osc_lib import utils as osc_utils
+from osc_lib.utils import columns as column_util
 
-from neutronclient.osc import utils as nc_osc_utils
 from neutronclient.osc.v2.networking_bgpvpn import bgpvpn
 from neutronclient.osc.v2.networking_bgpvpn import constants
 from neutronclient.tests.unit.osc.v2.networking_bgpvpn import fakes
 
 
 columns_short = tuple(col for col, _, listing_mode in bgpvpn._attr_map
-                      if listing_mode in (nc_osc_utils.LIST_BOTH,
-                                          nc_osc_utils.LIST_SHORT_ONLY))
+                      if listing_mode in (column_util.LIST_BOTH,
+                                          column_util.LIST_SHORT_ONLY))
 columns_long = tuple(col for col, _, listing_mode in bgpvpn._attr_map
-                     if listing_mode in (nc_osc_utils.LIST_BOTH,
-                                         nc_osc_utils.LIST_LONG_ONLY))
+                     if listing_mode in (column_util.LIST_BOTH,
+                                         column_util.LIST_LONG_ONLY))
 headers_short = tuple(head for _, head, listing_mode in bgpvpn._attr_map
-                      if listing_mode in (nc_osc_utils.LIST_BOTH,
-                                          nc_osc_utils.LIST_SHORT_ONLY))
+                      if listing_mode in (column_util.LIST_BOTH,
+                                          column_util.LIST_SHORT_ONLY))
 headers_long = tuple(head for _, head, listing_mode in bgpvpn._attr_map
-                     if listing_mode in (nc_osc_utils.LIST_BOTH,
-                                         nc_osc_utils.LIST_LONG_ONLY))
+                     if listing_mode in (column_util.LIST_BOTH,
+                                         column_util.LIST_LONG_ONLY))
 sorted_attr_map = sorted(bgpvpn._attr_map, key=operator.itemgetter(1))
 sorted_columns = tuple(col for col, _, _ in sorted_attr_map)
 sorted_headers = tuple(head for _, head, _ in sorted_attr_map)
@@ -64,6 +64,7 @@ class TestCreateBgpvpn(fakes.TestNeutronClientBgpvpn):
             ('name', None),
             ('type', 'l3'),
             ('vni', None),
+            ('local_pref', None),
             ('route_targets', None),
             ('import_targets', None),
             ('export_targets', None),
@@ -85,6 +86,7 @@ class TestCreateBgpvpn(fakes.TestNeutronClientBgpvpn):
             'name': 'fake_name',
             'type': 'l2',
             'vni': 100,
+            'local_pref': 777,
             'route_targets': ['fake_rt1', 'fake_rt2', 'fake_rt3'],
             'import_targets': ['fake_irt1', 'fake_irt2', 'fake_irt3'],
             'export_targets': ['fake_ert1', 'fake_ert2', 'fake_ert3'],
@@ -98,6 +100,7 @@ class TestCreateBgpvpn(fakes.TestNeutronClientBgpvpn):
             '--name', fake_bgpvpn['name'],
             '--type', fake_bgpvpn['type'],
             '--vni', str(fake_bgpvpn['vni']),
+            '--local-pref', str(fake_bgpvpn['local_pref']),
         ]
         for rt in fake_bgpvpn['route_targets']:
             arglist.extend(['--route-target', rt])
@@ -112,6 +115,7 @@ class TestCreateBgpvpn(fakes.TestNeutronClientBgpvpn):
             ('name', fake_bgpvpn['name']),
             ('type', fake_bgpvpn['type']),
             ('vni', fake_bgpvpn['vni']),
+            ('local_pref', fake_bgpvpn['local_pref']),
             ('route_targets', fake_bgpvpn['route_targets']),
             ('import_targets', fake_bgpvpn['import_targets']),
             ('export_targets', fake_bgpvpn['export_targets']),
